
.\" Copyright (c), 2005 Dan McMahill
.\" Do not edit this directly.  Edit the XML source file instead
.\"

.TH parallel_rc_p2s "" "" "Wcalc" "Wcalc Commands"
.B parallel_rc_p2s
- Convert Parallel RC Network into Equivalent Series RC Network

.SH SYNOPSIS

[] = 
parallel_rc_p2s(Cp, Rp, Qp, freq, flag, Cs, Rs, Qs, Cp, Rp, Qp)


.SH INPUT PARAMETERS

.TP 10
Cp
: Parallel capacitance (Farads)
.TP 10
Rp
: Parallel resistance (Ohms)
.TP 10
Qp
: Parallel quality factor
.TP 10
freq
: Analysis frequency (Hertz)
.TP 10
flag
: indicates if Qs or Rs should be used for the loss input
    
.RS
.TP 10
flag=0
: Qs will be calculated from Rs.
.TP 10
flag=1
: Rs will be calculated from Qs.
.RE

.TP 10
Cs
: Series capacitance (Farads)
.TP 10
Rs
: Series resistance (Ohms)
.TP 10
Qs
: Series quality factor
.TP 10
Cp
: Parallel capacitance (Farads)
.TP 10
Rp
: Parallel resistance (Ohms)
.TP 10
Qp
: Parallel quality factor

.SH OUTPUT VALUES

.SH DESCRIPTION

Function to calculate an equivalent series RC network from an input
parallel RC network.

.SH EXAMPLE
.nf

.TP
 // 10 pF
Cp=10e-12;
.TP
 // 5 kOhms
Rp=5e3;
.TP
 // This value will be replaced
Qp=100;
.TP
 // 100 MHz operation
f=100e6;
.TP
 // Use Rp (and calculate Qp)
flag=0;
[Cs, Rs, Qs, Cp, Rp, Qp] = parallel_rc_p2s(Cp, Rp,
  Qp, f, flag);
disp(sprintf('Equivalent series C = %g pF', Cs/1e-12));
disp(sprintf('Equivalent series R = %g Ohm', Rs));
disp(sprintf('Quality factor      =%g',Qs));
.fi
.SH SEE ALSO
stdio-wcalc(1),
air_coil_calc(), air_coil_syn(), coax_calc(), bars_calc(), coax_syn(), coplanar_calc(), coplanar_syn(), coupled_microstrip_calc(), coupled_microstrip_syn(), coupled_stripline_calc(), coupled_stripline_syn(), ic_microstrip_calc(), ic_microstrip_syn(), microstrip_calc(), microstrip_syn(), parallel_rc_p2s(), parallel_rc_s2p(), stripline_calc(), stripline_syn()
.SH AUTHOR

Dan McMahill

.SH BUGS

None known
